This is a simple module which allows you to get information about one or multiple youtube videos.

You can finish multiple of urls by saying:

finish(['URL', 'URL'])

But you can also just finish one by saying:

finish('URL')


you can also get each piece of info by calling either:

print(likes(url))
print(views(url))
print(subs(url))
print(dislikes(url))
print(creator(url))
print(is_private(url))
print(average_rating(url))
